"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Execution = void 0;
/**
 * Template execution, holds contexts, extra helpers, data.
 */
class Execution {
    /**
     * Template execution, holds contexts, extra helpers, data.
     *
     * @param {object[]} contexts Contexts from which bigodon path expressions will evaluate
     * @param {Map<string, Function>} extraHelpers Extra helpers that can be called other than default bigodon helpers
     * @param {object?} data Data that cannot be accessed from the template but can be accessed and modified from helpers
     */
    constructor(contexts, extraHelpers, data) {
        this.contexts = contexts;
        this.extraHelpers = extraHelpers;
        this.data = data;
    }
    /**
     * Current context to be used by path expressions.
     *
     * @return {object} Current context to be used by path expressions.
     */
    get context() {
        return this.contexts[this.contexts.length - 1];
    }
    /**
     * Creates Execution from current one with new child context.
     * Used to change context allowing for $parent and $root access of previous contexts.
     *
     * @param {object} context New child context to be used by path expressions
     * @return {Execution} Execution with the added context
     */
    withChildContext(context) {
        return new Execution([...this.contexts, context], this.extraHelpers);
    }
    /**
     * Creates an execution from context, helpers and options.
     *
     * @param {object} context Context from which bigodon path expressions will evaluate
     * @param {Map<string, Function>?} extraHelpers Extra helpers that can be called other than default bigodon helpers
     * @param {BigodonOptions} options Options for the current execution only
     * @return {Execution}
     */
    static of(context, extraHelpers = new Map(), options = {}) {
        return new Execution([context], extraHelpers, options.data);
    }
}
exports.Execution = Execution;
