"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.stringHelpers = void 0;
const utils_1 = require("../../utils");
const uuid_1 = require("uuid");
const append = (...args) => args.map(a => String(a)).join('');
const uppercase = (str) => String(str).toUpperCase();
const lowercase = (str) => String(str).toLowerCase();
const split = (str, separator) => String(str).split(String(separator));
const startsWith = (str, prefix) => String(str).startsWith(String(prefix));
const endsWith = (str, suffix) => String(str).endsWith(String(suffix));
const trim = (str) => String(str).trim();
const trimLeft = (str) => String(str).trimLeft();
const trimRight = (str) => String(str).trimRight();
const toString = (obj) => String(obj);
const replace = (str, from, to) => String(str).split(String(from)).join(String(to));
function capitalize(str) {
    const strng = String(str);
    return strng.charAt(0).toUpperCase() + strng.slice(1);
}
function capitalizeAll(str) {
    const strng = String(str);
    return strng.replace(/\w\S*/g, txt => txt.charAt(0).toUpperCase() + txt.substr(1).toLowerCase());
}
function substring(str, start, end) {
    (0, utils_1.ensure)(typeof start === 'number', 'start must be a number');
    (0, utils_1.ensure)(typeof end === 'number' || typeof end === 'undefined', 'end must be a number or undefined');
    return String(str).substring(start, end);
}
function padLeft(str, length, char) {
    (0, utils_1.ensure)(typeof length === 'number', 'length must be a number');
    (0, utils_1.ensure)(typeof char === 'undefined' || typeof char === 'string', 'char must be a string or undefined');
    (0, utils_1.ensure)(typeof char === 'undefined' || char.length === 1, 'char must be a single character');
    return String(str).padStart(length, char);
}
function padRight(str, length, char) {
    (0, utils_1.ensure)(typeof length === 'number', 'length must be a number');
    (0, utils_1.ensure)(typeof char === 'undefined' || typeof char === 'string', 'char must be a string or undefined');
    (0, utils_1.ensure)(typeof char === 'undefined' || char.length === 1, 'char must be a single character');
    return String(str).padEnd(length, char);
}
exports.stringHelpers = Object.assign(Object.create(null), {
    append, upper: uppercase, upcase: uppercase, uppercase,
    lowercase, down: lowercase, lower: lowercase, padRight,
    lowcase: lowercase, downcase: lowercase, capitalize,
    capitalizeAll, padStart: padLeft, padEnd: padRight, trim,
    capitalizeFirst: capitalize, toString, split, startsWith,
    endsWith, trimLeft, trimRight, trimStart: trimLeft,
    trimEnd: trimRight, replace, substring, padLeft,
    capitalizeWords: capitalizeAll, uuid: uuid_1.v4,
});
